import { useState } from "react";
import { Button, Container, Row } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import ManagedBoatTile from "../../components/ManagedBoatTile";
import { faPlus } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import StaffModal from "../../components/StaffModal"

function BoatManager() {
	const { t } = useTranslation();
	const [addElement, setAddElement] = useState<any>(false);
	const [infoElement, setInfoElement] = useState<any>(false);
	const [blockElement, setBlockElement] = useState<any>(false);
	const [unblockElement, setUnBlockElement] = useState<any>(false);

	const boats = [{ id: 1, boatName: "Nicholas Unless-Jesus-Christ-Had-Died-For-Thee-Thou-Hadst-Been-Damned Barbon", time: "13:15-15:14", seats: 2, blocked: true }, { id: 2, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: true }, { id: 3, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: true },
	{ id: 4, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: true }, { id: 5, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: true }, { id: 6, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: true },
	{ id: 7, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false }, { id: 8, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false }, { id: 9, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false },
	{ id: 10, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false }, { id: 11, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false }, { id: 12, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, blocked: false },]


	return (
		<div className="text-center position-relative">
			<h2 className="d-flex justify-content-center my-3">{t("boatManager.blockedBoats")}</h2>
			{/*TODO: Make dynamic*/}
			<div className="py-3 bg-light border">
				<Container>
					<div className="blocked-tiles text-center">
						<Row xs={1} md={2} xxl={3}>
							{boats.filter(x => x.blocked).map(x =>
								<ManagedBoatTile key={x.id} boatName={x.boatName} onInfoClick={() => { setInfoElement(x) }} onBlockClick={() => { setUnBlockElement(x) }} blocked={true}></ManagedBoatTile>
							)}
						</Row>
					</div>
					<Button variant="light" className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
				</Container>
			</div>

			<h2 className="my-3">{t("boatManager.availableBoats")}</h2>
			<div className="py-3 bg-light border">
				<Container>
					<div className="blocked-tiles text-center">
						<Row xs={1} md={2} xxl={3}>
							{boats.filter(x => !x.blocked).map(x =>
								<ManagedBoatTile key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} onInfoClick={() => { setInfoElement(x) }} onBlockClick={() => { setBlockElement(x) }} blocked={false}></ManagedBoatTile>
							)}
						</Row>
					</div>
					<Button variant="light" className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
				</Container>
			</div>
			<div className="d-flex px-2 py-1 justify-content-end bg-white border-top" style={{ position: "sticky", right: "5px", bottom: "0", zIndex: 3 }}>
				<Button onClick={() => { setAddElement(true) }} variant="secondary"><FontAwesomeIcon icon={faPlus} className="text-white me-2" />{t("boatManager.addBoat")}</Button>
			</div>
			<StaffModal header={t("boatManager.addBoat")} show={addElement} successText={t("boatManager.Add")} onHide={() => { setAddElement(false) }} onSuccess={() => { setAddElement(false) }}>
			</StaffModal>
			<StaffModal header={t("boatManager.InfoBoat")} show={infoElement} successText={t("boatManager.Info")} onHide={() => { setInfoElement(false) }} onSuccess={() => { setInfoElement(false) }}>
			</StaffModal>
			<StaffModal header={t("boatManager.BlockBoat")} show={blockElement} successText={t("boatManager.Block")} onHide={() => { setBlockElement(false) }} onSuccess={() => { setBlockElement(false) }}>
			</StaffModal>
			<StaffModal header={t("boatManager.UnblockBoat")} show={unblockElement} successText={t("boatManager.Unblock")} onHide={() => { setUnBlockElement(false) }} onSuccess={() => { setUnBlockElement(false) }}>
			</StaffModal>
		</div >
	);
}

export default BoatManager;
