import { Request, Response } from "express";
import CheckIn from "../db/models/CheckIn";
import Boat from "../db/models/Boat";
import BoatType from "../db/models/BoatType";

//create log entry
const createLogEntryController = async (req: Request, res: Response) => {
  try {

    //get input
    const logEntry = req.body;

    //find related boat using given boatId
    const chosenBoat = await Boat.findByPk(logEntry.boatId);

    //if boat not found
    if (!chosenBoat) {
      return res
        .status(404)
        .json({ success: false, error: "givenBoatIdNotFound" });
    }

    //get status of boat
    const bootAvailability = chosenBoat.status;

    //if boat status is false => is not available => boat locked
    if (bootAvailability === false) {
      return res.status(409).json({ success: false, error: "BoatLocked" });
    }

    //check if number of additional clients == number of seats - 1 (responsable client)
    const numOfAdditionalClients = logEntry.additionalClients.length;
    const boatTypeOfChosenBoat = await BoatType.findByPk(chosenBoat.boattype); //number of seats of any boat can be found in its boattype
    if (numOfAdditionalClients !== boatTypeOfChosenBoat.seats - 1) { //minus responsable client
      return res.status(404).json({
        success: false,
        error: "numOfAllGivenClientsDoesNotMatchNumOfChosenBoatSeats",
      });
    }

    //create entry
    const newLogEntry = await CheckIn.create(logEntry);

    //return result after checking all possible error-cases
    return res.status(201).json({
      success: true,
      result: {
        startTime: newLogEntry.startTime,
        estimatedEndTime: newLogEntry.estimatedEndTime,
        email: newLogEntry.email,
        fullNameOfResponsableClient: newLogEntry.fullNameOfResponsableClient,
        additionalClients: newLogEntry.additionalClients,
        boatID: newLogEntry.boatId,
      },
    });
  } catch (error) {
    console.error(error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};
export default createLogEntryController;
